#!/bin/bash

#Simplified version of the master_analysis.sh script: it cuts the single longest branch on each step

#rudy-2 needs a fully resolved backbone tree (except for the relationship in question, which will be a polytomy) to follow in the branch length optimization process


#Important formats:

#<allsppcladefile.csv> Must look like:
# Ogs,SpeciesA
# Ogs,SpeciesB
# Clade1,SpeciesC
# Clade2,SpeciesD
# Clade3,SpeciesE
# etc...

#<treeskeleton.nwk> Must look like:
#(Clade3,Clade2,Clade1,Ogs);
# In other words, it must keep the naming nomenclature of the clades as used on the allsppcladesfile.csv, and be readable by any tree editing software. I recommend the use of a star tree in which all clades are monophyletic.

#IMPORTANT: although it is not included on the arguments, if the gene uses partitions for RAxML, the partitions file (already in RAxML format) must be included on the working directory under the name $genename_partitions.txt

#Usage:
# %s <$genename> <alignment.phy> <allsppcladefile.csv> <ctrlfile_branchopts> <ctrlfile_podatest> <full_backbonetree.NEX> <$trimno>(JUST the number, will be 0 if left empty)

genename=$1
alignment=$2
fullcsv=$3
branchopts_ctlfi=$4
podatest_ctlfi=$5
fullbackbone=$6

minsppnumber=1 #this is the minimum number of species allowed for each clade


reducecsv_aa_path=/home/flugcanje/Desktop/Dktp/Developing/DEV_resieve/AAcids/scripts/reducecsv_aa.sh
producetrees_path=/home/flugcanje/Desktop/Dktp/Developing/DEV_resieve/AAcids/scripts/producetrees.sh
paml_blength_optimizer_aa_path=/home/flugcanje/Desktop/Dktp/Developing/DEV_resieve/AAcids/scripts/paml_blength_optimizer-aa.sh
tree_blengths_path=/home/flugcanje/Desktop/Dktp/Developing/DEV_resieve/AAcids/scripts/tree_blengths.sh
podatestA_aa_path=/home/flugcanje/Desktop/Dktp/Developing/DEV_resieve/AAcids/scripts/podatestA-aa.sh
trimalignment_sh_path=/home/flugcanje/Desktop/Dktp/Developing/DEV_resieve/AAcids/scripts/trimalignment.sh
fastophy_path=/home/flugcanje/Desktop/Dktp/Developing/DEV_resieve/AAcids/scripts/fastophy.sh
totalsumup_path=/home/flugcanje/Desktop/Dktp/Developing/DEV_resieve/AAcids/scripts/totalsumup.sh

cat $fullcsv | tr -d [:blank:] > tmp.tmp; mv tmp.tmp $fullcsv

if [[ -z "$7" ]]
then
  echo "
Trim number not given, starting from trim0
"
  trimno=0
else
  trimno=$7
fi

echo "That means that this is trim number $trimno"

exitstatus=in
extension=$(echo $alignment | rev | cut -d"." -f1 | rev)


echo "File extension was found to be $extension"

########:::START OF LOOOOOP

while [ "$exitstatus" != "out" ]
do

########:::PREPARATION STEPS

#produce the reduced .csv file, rename the alignment for a new trim step
  cp $alignment "$genename"_trim"$trimno".$extension
  if [[ -e nexttrim.phy ]]
  then
    rm nexttrim.phy
  fi
  alignment=$(echo "$genename"_trim"$trimno".$extension)
  prefix=$(echo "$genename"_trim"$trimno")
  echo "new alignment name is $alignment"
  echo "prefix is now $prefix"
echo "
Starting REDUCECSV-AA
"
  $reducecsv_aa_path $alignment $fullcsv
  genecsv=$(echo "$prefix"_cladespp.csv)

echo "
Starting PRODUCETREES
"
$producetrees_path $prefix $genecsv $fullcsv $fullbackbone $trimno

#exit # For Testing...

#puts the "I" on the first line of the phylip alignment, to make it ready for PAML (i.e. podatestA_aa)
  firstline=$(cat $alignment | head -n1)
  sed "s/$firstline/$firstline I/g" $alignment > $alignment.tmp
  mv $alignment.tmp $alignment

echo "
Starting PAML_BLENGTH_OPTIMIZER
"
$paml_blength_optimizer_aa_path $prefix "$prefix"_backbone.tree $branchopts_ctlfi

#exit #For testing....

echo "
Starting TREE_BLENGTHS
"
#getting the sum of branch lengths
$tree_blengths_path "$prefix"_bestTree.nwk $prefix $fullcsv


#runs the podatestA_aa script for the likelihood ratio rest
$podatestA_aa_path trim$trimno $podatest_ctlfi

#removes the "I" from the alignment for further processing
  sed "s/$firstline I/$firstline/g" $alignment > $alignment.tmp
  mv $alignment.tmp $alignment


########:::TRIMMING PART

#determines the amount of active clades, and exit if none
  echo "Active clades at trim$trimno:" > "$prefix"_active-clades.list
  for g in $(cat $fullcsv | grep Clade | cut -d"," -f1 | sort | uniq)
  do
    sppnum=$(cat "$prefix"_cladespp.csv | grep $g | wc -l)
    if [[ "$sppnum" -gt "$minsppnumber" ]]
    then
      echo $g >> "$prefix"_active-clades.list
    fi
  done
  activeclades=$(cat "$prefix"_active-clades.list | wc -l)
  if  [[ "$activeclades" == "1"  ]]
  then
    exitstatus=out
    echo "No more trimming possible" > "$prefix"_finalstatus.txt
    mv "$prefix"_* guidestartree* "$prefix".phy RAxML_results_"$prefix" "$prefix"
    break
  else
    existatus=in
  fi

#getting the taxon to be trimmed, forming the new taxalist
  for actclade in $(cat "$prefix"_active-clades.list | tail -n +2)
  do
    cat "$prefix"_"$actclade"_blengths.csv >> "$prefix"_fullactivetaxalist.csv
  done
  cat "$prefix"_fullactivetaxalist.csv | sort -t "," -k 2,2n | tail -n1 > "$prefix"_deadtaxon.csv
  cat "$prefix"_fullactivetaxalist.csv | sort -t "," -k 2,2n | head -n-1 > "$prefix"_activelivingtaxa.csv
  rm "$prefix"_fullactivetaxalist.csv

  cat $fullcsv | cut -d"," -f1 | sort | uniq > "$prefix"_tempocladelist.tmp
  cat "$prefix"_active-clades.list | tail -n +2 >> "$prefix"_tempocladelist.tmp
  cat "$prefix"_activelivingtaxa.csv > "$prefix"_fulllivingtaxa.csv
  for ti in $(cat "$prefix"_tempocladelist.tmp | sort | uniq -u)
  do
    cat "$prefix"_"$ti"_blengths.csv >> "$prefix"_fulllivingtaxa.csv
  done
  rm "$prefix"_tempocladelist.tmp

#trimming the alignment
  $trimalignment_sh_path $prefix.fasta "$prefix"_fulllivingtaxa.csv outalignment.fasta

  $fastophy_path outalignment.fasta nexttrim.phy
#  seqmagick convert outalignment.fasta nexttrim.phy
  rm outalignment.fasta $prefix.fasta

  mv "$prefix"_* guidestartree* "$prefix".phy RAxML_results_"$prefix" "$prefix"

  trimno=$(echo $trimno+1 | bc)
  alignment=$(echo nexttrim.phy)

  echo "New trim number is $trimno, and new alignment name is $alignment"
#exit #for testing
done
#exit #for testing

$totalsumup_path $genename

mkdir $genename
mv "$genename"_* $genename.phy $genename/
