#!/bin/bash

# Usage:
# %s <p-val_threshold> <outputfile.csv> <allcladessppfile.csv>

#Defines threshold to the first argument, otherwise defaults to p-0.05
if [ -z $1 ]
then
  echo "No threshold given. Defaulting to 0.05"
  tresh=0.05
else
  tresh=$1
fi

if [ -z $2 ]
then
  echo "No output filename given. Defaulting to output.csv"
  outfile=$(echo output.csv)
else
  outfile=$2
fi

genename=$(pwd | rev | cut -d"/" -f1 | rev)
echo "Evaluating $genename..."

#pvaleval function: evaluates the p-value at each trim step, and prints it if larger than given threshold
pvaleval () { for no in $(cat "$genename"_gene_claderates.csv | cut -d"," -f10 | tail -n+2 | sort -g)
do
  val=$(echo $no | sed 's/[eE]/*10^/g')
  if [[ $(echo "if ($val >= $tresh) 1 else 0" | bc) -eq 1 ]]
  then
    cat "$genename"_gene_claderates.csv | cut -d"," -f1,10 | tail -n+2 | grep ,$val$
  fi
done }

# takes the "earliest" trim step with a number over the given threshold
winningline=$(pvaleval | sort -g -t "," -k1 | head -n1)
mintrim=$(echo $winningline | cut -d"," -f1)
minpval=$(echo $winningline | cut -d"," -f2)

mixtaxlist=$(cut -d"," -f1 "$genename"_trim"$mintrim"/"$genename"_trim"$mintrim"_All_blengths.csv && cat $3 | cut -d"," -f2)
deadtaxa=$(echo $mixtaxlist | tr [[:blank:]] "\n" | sort | uniq -u | tr [[:space:]] ";" | sed 's/;$//g')

echo "$genename,$tresh,$mintrim,$minpval,$deadtaxa" >> "$outfile"
