#!/bin/bash
# This script makes a table of the relative rates of each clade through the trims (getting all ready for the trimsgraphds.R script)

# Usage:
# tabulatetrims genename

if [[ -z "$1" ]]
then
  echo "
Name of gene?
"
  read genename
else
  genename=$1
fi

curdir=$(pwd)
totdirs=$(ls -l | grep "^d" | grep "$genename"_trim | wc -l)
numtrims=$(echo $totdirs-1 | bc)

echo "Found $totdirs files with info

$numtrims trimming steps done"

#making header for a .csv file:
echo "Trim,Ogs,Clade1,Clade2,Clade3,C1P,C2P,C3P,lnLdiff,pval" > "$1"_gene_claderates.csv

#making first run (separated for reasons clear on next step)
echo "putting the 'trim0' data"
rates=$(cat "$curdir"/*trim0/Summary_*_trim0.txt | grep "3 clocks" | cut -d":" -f2 | tr -s [:blank:] | tr [:blank:] "," | cut -d"," -f2-)
lnLdiff=$(cat "$curdir"/*trim0/Summary_*_trim0.txt | grep "difference=" | cut -d"=" -f2 | tr -d [:blank:])
chisq=$(echo $lnLdiff*2 | bc)
pval=$(echo "pchisq("$chisq",df=2,lower.tail=FALSE)" | R --no-save | tail -n -2 | head -n -1 | cut -d"]" -f2 | tr -d [:blank:])


#Determining which is the slowest clade at trim0. All consequent rates will be expressed as percentages of this one
dipr=$(echo $rates | cut -d"," -f2)
lorr=$(echo $rates | cut -d"," -f3)
silr=$(echo $rates | cut -d"," -f4)
echo "Which correspond to $dipr $lorr $silr?"
#lowest=$(echo -e $dipr"\n"$lorr"\n"$silr | sort -n | head -n1)
lowest=$(echo $dipr)
#echo "slowest of all these is $lowest"

#if [[ "$dipr" == "$lowest" ]]
#then
#  option="slowdip"
#elif [[ "$lorr" == "$lowest" ]]
#then
#  option="slowlor"
#elif [[ "$silr" == "$lowest" ]]
#then
#  option="slowsil"
#else
#  echo "There must have been a misunderstsanding. I was not able to determine which of the three initial rates was the slowest"
#  exit
#fi

option="slowdip"

echo "***Entering option $option***"

normdip=$(echo "$dipr $lowest" | awk '{printf "%f", $1/$2*100}')
normlor=$(echo "$lorr $lowest" | awk '{printf "%f", $1/$2*100}')
normsil=$(echo "$silr $lowest" | awk '{printf "%f", $1/$2*100}')

#Writing results of the trim0 to table
echo 0,NA,$dipr,$lorr,$silr,$normdip,$normlor,$normsil,$lnLdiff,$pval>> "$1"_gene_claderates.csv



#Organizing the data from trim1 onwards, normalizing the rates to the % of the slowest rate

#Option SlowDip
if [[ "$option" == "slowdip" ]]
then
  for i in $(seq 1 $numtrims)
  do
    echo "putting data from trim $i"
    rates=$(cat "$curdir"/*trim$i/Summary_*_trim$i.txt | grep "3 clocks" | cut -d":" -f2 | tr -s [:blank:] | tr [:blank:] "," | cut -d"," -f2-)
    lnLdiff=$(cat "$curdir"/*trim$i/Summary_*_trim$i.txt | grep "difference=" | cut -d"=" -f2 | tr -d [:blank:])
    chisq=$(echo $lnLdiff*2 | bc)
    pval=$(echo "pchisq("$chisq",df=2,lower.tail=FALSE)" | R --no-save | tail -n -2 | head -n -1 | cut -d"]" -f2 | tr -d [:blank:])

    dipr=$(echo $rates | cut -d"," -f2)
    lorr=$(echo $rates | cut -d"," -f3)
    silr=$(echo $rates | cut -d"," -f4)  

    normdip=$(echo "$dipr $dipr" | awk '{printf "%f", $1/$2*100}')
    normlor=$(echo "$lorr $dipr" | awk '{printf "%f", $1/$2*100}')
    normsil=$(echo "$silr $dipr" | awk '{printf "%f", $1/$2*100}')

    echo $i,NA,$dipr,$lorr,$silr,$normdip,$normlor,$normsil,$lnLdiff,$pval >> "$1"_gene_claderates.csv

    if [ -e "$curdir"/*trim$i/*Alltocut.csv ]
    then
      echo "

**Trim$i trimmed the following taxa:
" >> "$genename"_taxa_removed.txt
      cat "$curdir"/*trim$i/*Alltocut.csv | tr "," "\t" >> "$genename"_taxa_removed.txt
    fi

  done


#Option SlowLor
elif [[ "$option" == "slowlor" ]]
then
  for i in $(seq 1 $numtrims)
  do
    echo "putting data from trim $i"
    rates=$(cat "$curdir"/*trim$i/Summary_*_trim$i.txt | grep "3 clocks" | cut -d":" -f2 | tr -s [:blank:] | tr [:blank:] "," | cut -d"," -f2-)
    lnLdiff=$(cat "$curdir"/*trim$i/Summary_*_trim$i.txt | grep "difference=" | cut -d"=" -f2 | tr -d [:blank:])
    chisq=$(echo $lnLdiff*2 | bc)
    pval=$(echo "pchisq("$chisq",df=2,lower.tail=FALSE)" | R --no-save | tail -n -2 | head -n -1 | cut -d"]" -f2 | tr -d [:blank:])

    dipr=$(echo $rates | cut -d"," -f2)
    lorr=$(echo $rates | cut -d"," -f3)
    silr=$(echo $rates | cut -d"," -f4)  

    normdip=$(echo "$dipr $lorr" | awk '{printf "%f", $1/$2*100}')
    normlor=$(echo "$lorr $lorr" | awk '{printf "%f", $1/$2*100}')
    normsil=$(echo "$silr $lorr" | awk '{printf "%f", $1/$2*100}')

    echo $i,NA,$dipr,$lorr,$silr,$normdip,$normlor,$normsil,$lnLdiff,$pval >> "$1"_gene_claderates.csv

    if [ -e "$curdir"/*trim$i/*Alltocut.csv ]
    then
      echo "

**Trim$i trimmed the following taxa:
" >> "$genename"_taxa_removed.txt
      cat "$curdir"/*trim$i/*Alltocut.csv | tr "," "\t" >> "$genename"_taxa_removed.txt
    fi

  done


#Option SlowSil
elif [[ "$option" == "slowsil" ]]
then
  for i in $(seq 1 $numtrims)
  do
    echo "putting data from trim $i"
    rates=$(cat "$curdir"/*trim$i/Summary_*_trim$i.txt | grep "3 clocks" | cut -d":" -f2 | tr -s [:blank:] | tr [:blank:] "," | cut -d"," -f2-)
    lnLdiff=$(cat "$curdir"/*trim$i/Summary_*_trim$i.txt | grep "difference=" | cut -d"=" -f2 | tr -d [:blank:])
    chisq=$(echo $lnLdiff*2 | bc)
    pval=$(echo "pchisq("$chisq",df=2,lower.tail=FALSE)" | R --no-save | tail -n -2 | head -n -1 | cut -d"]" -f2 | tr -d [:blank:])

    dipr=$(echo $rates | cut -d"," -f2)
    lorr=$(echo $rates | cut -d"," -f3)
    silr=$(echo $rates | cut -d"," -f4)  

    normdip=$(echo "$dipr $silr" | awk '{printf "%f", $1/$2*100}')
    normlor=$(echo "$lorr $silr" | awk '{printf "%f", $1/$2*100}')
    normsil=$(echo "$silr $silr" | awk '{printf "%f", $1/$2*100}')

    echo $i,NA,$dipr,$lorr,$silr,$normdip,$normlor,$normsil,$lnLdiff,$pval >> "$1"_gene_claderates.csv

    if [ -e "$curdir"/*trim$i/*Alltocut.csv ]
    then
      echo "

**Trim$i trimmed the following taxa:
" >> "$genename"_taxa_removed.txt
      cat "$curdir"/*trim$i/*Alltocut.csv | tr "," "\t" >> "$genename"_taxa_removed.txt
    fi

  done

else
  echo "Was not able to find a corresponding option"
  exit
fi
