# R script to take in an input tree, and label all nodes; that later on bash will be used to produce the tree with the Siluroidei, Loricarioidei, etc. nodes declared

# Usage:
# Rscript /bin/labelnodes.R <input_tree.NEX> <outputtreename.tree> <Clade1(Dips)stay.csv> <Clade2(Lors)stay.csv> <Clade3(Sils)stay.csv>

library(adephylo)
library(ape)

arg = commandArgs(trailingOnly=TRUE)

t1 <- ladderize(read.nexus(file=arg[1]),right=TRUE) #tree for trimming
lors<-as.matrix(read.csv(file=arg[4],header=FALSE)) #lors that won't be cut
sils<-as.matrix(read.csv(file=arg[5],header=FALSE)) #sils that won't be cut
dips<-as.matrix(read.csv(file=arg[3],header=FALSE)) #dips that won't be cut

t1x<-makeNodeLabel(t1,method="number",prefix="N_") #labeling all the nodes
write.tree(t1x,file=arg[2]) #writes trimmed fully labeled tree to file
m2<-t(as.matrix(treePart(t1x,result=c("dummy")))) #matrix of tips and the clades they belong to (t transposes)

t1Ls.df<-as.data.frame(m2[,lors[,"V1"]]) #nodes that all Lors share as dataframe
t1Ss.df<-as.data.frame(m2[,sils[,"V1"]]) #nodes that all Sils share as dataframe
t1Ds.df<-as.data.frame(m2[,dips[,"V1"]]) #nodes that all dips share as dataframe

Lnod<-as.list(rownames(tail(t1Ls.df[rowSums(t1Ls.df) == ncol(t1Ls.df),],1))) #Lornode defined
Snod<-as.list(rownames(tail(t1Ss.df[rowSums(t1Ss.df) == ncol(t1Ss.df),],1))) #Silnode defined
Dnod<-as.list(rownames(tail(t1Ds.df[rowSums(t1Ds.df) == ncol(t1Ds.df),],1))) #Dipnode defined

#prints the node numbers to file
sink("nodes.txt")
if (length(dips) > 1) {
print(c("Clade1>",Dnod[[1]]))
}
if (length(lors) > 1) {
print(c("Clade2>",Lnod[[1]]))
}
if (length(sils) > 1) {
print(c("Clade3>",Snod[[1]]))
}
sink()
