#!/bin/bash
# This script takes in a .phy or fasta alignment (.fas, .fasta, .fst), and a .csv file in which all taxa are included along with the clade to which they belong (example of format below), and produces a reduced version of the .csv file that includes only the taxa present on the alignment.

# Example of csv file:
# Ogs,Species1
# Clade1,Species2
# Clade2,Species3
# Clade2,Species4
# Clade3,Species5
# Clade3,Species6
# etc...

#Usage:
# reducecsv.sh <alignment.phy/fas> <allsppwcladelabels.csv>

alignment=$1
fullcsv=$2

phytofas_path=/home/flugcanje/Desktop/Dktp/Developing/DEV_resieve/REsieve/scripts/phytofas.sh

echo "Making a reduced allsppcladesfile for $alignment using $fullcsv"

extension=$(echo $alignment | rev | cut -d"." -f1 | rev)
prefix=$(echo $alignment | sed "s/.$extension//g")

# Checks if alignment has a fasta or phylip format, and if in phylip, converts it to fasta
if [[ "$extension" == "phy" ]]
then
  echo "File has $extension as extension, PHYLIP format, to be converted to fasta"
  $phytofas_path $prefix.phy $prefix.fasta
#  seqmagick convert $prefix.phy $prefix.fasta
  alignment=$(echo $prefix.fasta)
elif [[ "$extension" == "fasta" ]] || [[ "$extension" == "fas" ]] || [[ "$extension" == "fst" ]]
  then
  echo "Input file is $extension, No need for conversion"
else
  echo "Alignment extension not recognized. Exiting..."
  exit
fi

for spp in $(cat $alignment | grep ">" | cut -d">" -f2)
do
  cat $fullcsv | grep -w $spp >> desordenados.list
done

cat desordenados.list | sort > "$prefix"_cladespp.csv
rm desordenados.list $prefix.fasta
