#!/bin/bash
# This script takes a tree file with branch lengths and gives a .csv file with the per-taxon branch lengths
# OPTIONAL: can also give separate files for each clade as declared on an input file


# Suggested usage:
# tree_blengths treefile.tree gene_trim fulltaxonlist(optional).txt

patristic_dists_path=/home/flugcanje/Desktop/Dktp/Developing/DEV_resieve/REsieve/scripts/patristic_dists.R


if [[ -z "$1" ]]
then
  echo "
ERROR: Did not give any input tree file (put it on first argument)
"
  exit
else
  treefile=$1
fi

Rscript $patristic_dists_path $treefile soblengths.csv.tmp
cat soblengths.csv.tmp | tail -n +2 | tr -s [:blank:] | tr " " "," > soblengths.csv
rm soblengths.csv.tmp

if [[ -z "$2" ]]
then
  echo "
gene_trim?"
  read gentrim
else
  gentrim=$2
fi

if [[ -z "$3" ]]
then
  echo "
No file with full taxon list (and declared clades) was given, so independent branch lengths files for each clade will not be made"
else
  echo "
Taxon list file $3 given, independent branch length files will be made for each clade"
  cat $3 | cut -d"," -f1 | uniq > groups.list
  grpnums=$(cat groups.list | wc -l)
  for i in $(seq 1 $grpnums)
  do
    clade=$(cat groups.list | head -n$i | tail -n1)
    cat $3 | grep -w $clade | cut -d"," -f2 > "$clade"_list.tmp
    totsp=$(cat "$clade"_list.tmp | wc -l)
    for n in $(seq 1 $totsp)
    do
      sp=$(cat "$clade"_list.tmp | head -n$n | tail -n1)
      cat soblengths.csv | grep -w $sp >> "$clade"_blengths.tmp
    done
  cat "$clade"_blengths.tmp | tr "," " " | sort -k2 -n | tr " " "," >  "$gentrim"_"$clade"_blengths.csv
  rm "$clade"_list.tmp "$clade"_blengths.tmp
  done
  rm groups.list
fi


echo "Saving output to "$gentrim"_All_blengths.csv"
mv soblengths.csv "$gentrim"_All_blengths.csv


